@@ -21,6 +21,7 @@ __email__ = "poul@mpie.de"
 __status__ = "production"
 __date__ = "Jun 17, 2020"
 
+
 def _normalize(key):
     if isinstance(key, str):
         if key.isdecimal():
@@ -34,7 +35,6 @@ def _normalize(key):
     return key
 
 
-
 class InputList(MutableMapping):
     """
     Mutable sequence with optional keys.
@@ -159,10 +159,10 @@ class InputList(MutableMapping):
 
         return instance
 
-    def __init__(self, init = None, table_name = None):
+    def __init__(self, init=None, table_name=None):
         self.table_name = table_name
-        if init != None:
-            self.update(init, wrap = True)
+        if init is not None:
+            self.update(init, wrap=True)
 
     def __len__(self):
         return len(self._store)
@@ -182,17 +182,17 @@ class InputList(MutableMapping):
             return self[key[0]][key[1:]]
 
         elif isinstance(key, int):
-
             try:
                 return self._store[key]
             except IndexError:
                 raise IndexError("list index out of range") from None
-        elif isinstance(key, str):
 
+        elif isinstance(key, str):
             try:
                 return self._store[self._indices[key]]
             except KeyError:
                 raise KeyError(repr(key)) from None
+
         else:
             raise ValueError(
                     "{} is not a valid key, must be str or int".format(key)
@@ -292,13 +292,9 @@ class InputList(MutableMapping):
     def __repr__(self):
         name = self.__class__.__name__
         if self.has_keys():
-            return name + "({" + \
-                    ", ".join("{!r}: {!r}".format(k, v) for k, v in self.items()) + \
-            "})"
+            return name + "({" + ", ".join("{!r}: {!r}".format(k, v) for k, v in self.items()) + "})"
         else:
-            return name + "([" + \
-                    ", ".join("{!r}".format(v) for v in self._store) + \
-            "])"
+            return name + "([" + ", ".join("{!r}".format(v) for v in self._store) + "])"
 
     @classmethod
     def _wrap_val(cls, val):
@@ -329,13 +325,12 @@ class InputList(MutableMapping):
             "finished.".format(cls.__name__)
         )
 
-    def to_builtin(self, stringify = False):
+    def to_builtin(self, stringify=False):
         """
         Convert the list back to builtin dict"s and list"s recursively.
 
         Args:
-            stringify (bool, optinal): convert all non-recursive elements to
-            str
+            stringify (bool, optional): convert all non-recursive elements to str
         """
 
         if self.has_keys():
@@ -347,25 +342,25 @@ class InputList(MutableMapping):
                 # transparent for the rest of the module
                 k = str(k)
                 if isinstance(v, InputList):
-                    dd[k] = v.to_builtin(stringify = stringify)
+                    dd[k] = v.to_builtin(stringify=stringify)
                 else:
                     dd[k] = repr(v) if stringify else v
 
             return dd
         elif stringify:
-            return list(v.to_builtin(stringify = stringify)
-                            if isinstance(v, InputList) else repr(v)
-                                for v in self.values())
+            return list(v.to_builtin(stringify=stringify)
+                        if isinstance(v, InputList) else repr(v)
+                        for v in self.values())
         else:
-            return list(v.to_builtin(stringify = stringify)
-                            if isinstance(v, InputList) else v
-                                for v in self.values())
+            return list(v.to_builtin(stringify=stringify)
+                        if isinstance(v, InputList) else v
+                        for v in self.values())
 
     # allows "nice" displays in jupyter notebooks
     def _repr_json_(self):
-        return self.to_builtin(stringify = True)
+        return self.to_builtin(stringify=True)
 
-    def get(self, key, default = None, create = False):
+    def get(self, key, default=None, create=False):
         """
         If ``key`` exists, behave as generic, if not call create_group.
 
@@ -384,9 +379,9 @@ class InputList(MutableMapping):
         if create and key not in self:
             return self.create_group(key)
         else:
-            return super().get(key, default = default)
+            return super().get(key, default=default)
 
-    def update(self, init, wrap = False, **kwargs):
+    def update(self, init, wrap=False, **kwargs):
         """
         Add all elements or key-value pairs from init to this list.  If wrap is
         not given, behaves as the generic method.
@@ -444,7 +439,7 @@ class InputList(MutableMapping):
         for v in vals:
             self.append(v)
 
-    def insert(self, index, val, key = None):
+    def insert(self, index, val, key=None):
         """
         Add a new element to the list at the specified position, with an optional
         key.  If the key is already in the list it will be updated to point to
@@ -456,7 +451,7 @@ class InputList(MutableMapping):
             val:                    new element to add
             key (str, optional):    optional key to mark the new element
         """
-        if key != None:
+        if key is not None:
             for k, i in self._indices.items():
                 if i >= index:
                     self._indices[k] = i + 1
@@ -531,7 +526,7 @@ class InputList(MutableMapping):
         # same underlying data storage, so instead we have to do a shallow copy
         # of those manually
         copiee = type(self)()
-        copiee._store  = copy.copy(self._store)
+        copiee._store = copy.copy(self._store)
         copiee._indices = copy.copy(self._indices)
         copiee.table_name = self.table_name
         return copiee
@@ -607,7 +602,7 @@ class InputList(MutableMapping):
             data = hdf["data"]
 
         self.clear()
-        self.update(data, wrap = True)
+        self.update(data, wrap=True)
 
     def nodes(self):
         """
